@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,7 +11,7 @@
 
 class QTabWidget;
 
-namespace Akonadi
+namespace ContactEditor
 {
 class ContactViewer;
 class ContactGroupViewer;
@@ -37,8 +37,8 @@ public:
 
 private:
     KContacts::Addressee mContact;
-    Akonadi::ContactViewer *mContactViewer = nullptr;
-    Akonadi::ContactGroupViewer *mGroupViewer = nullptr;
+    ContactEditor::ContactViewer *mContactViewer = nullptr;
+    ContactEditor::ContactGroupViewer *mGroupViewer = nullptr;
 
     KAddressBookGrantlee::GrantleeContactFormatter *mFormatter = nullptr;
     KAddressBookGrantlee::GrantleeContactGroupFormatter *mGroupFormatter = nullptr;
