@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef DEFAULTCOMPLETION_H
-#define DEFAULTCOMPLETION_H
+#pragma once
 
 #include <QStringList>
 
@@ -13,5 +12,3 @@ namespace DefaultCompletion
 Q_REQUIRED_RESULT QStringList defaultCompetion();
 Q_REQUIRED_RESULT QStringList defaultOptions();
 }
-
-#endif // DEFAULTCOMPLETION_H
